Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(61)

Unified Diff: chrome/renderer/media/cast_ipc_dispatcher.h

Issue 1123733002: [chrome/renderer/media] Replace MessageLoopProxy usage with ThreadTaskRunnerHandle (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Fixed nit Created 5 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/renderer/media/cast_ipc_dispatcher.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/renderer/media/cast_ipc_dispatcher.h
diff --git a/chrome/renderer/media/cast_ipc_dispatcher.h b/chrome/renderer/media/cast_ipc_dispatcher.h
index a7c646fdfa2f0a4289ac2020fb625ba7bec47311..58c95e87c08d754d3898ec8ca0d0bec0c4224dcd 100644
--- a/chrome/renderer/media/cast_ipc_dispatcher.h
+++ b/chrome/renderer/media/cast_ipc_dispatcher.h
@@ -7,6 +7,7 @@
#include "base/callback.h"
#include "base/id_map.h"
+#include "base/thread_task_runner_handle.h"
#include "ipc/ipc_channel_proxy.h"
#include "ipc/message_filter.h"
#include "media/cast/cast_sender.h"
@@ -20,7 +21,7 @@ class CastTransportSenderIPC;
class CastIPCDispatcher : public IPC::MessageFilter {
public:
explicit CastIPCDispatcher(
- const scoped_refptr<base::MessageLoopProxy>& io_message_loop);
+ const scoped_refptr<base::SingleThreadTaskRunner>& io_task_runner);
static CastIPCDispatcher* Get();
void Send(IPC::Message* message);
@@ -60,8 +61,8 @@ class CastIPCDispatcher : public IPC::MessageFilter {
// For IPC Send(); must only be accesed on |io_message_loop_|.
IPC::Sender* sender_;
- // Message loop on which IPC calls are driven.
- const scoped_refptr<base::MessageLoopProxy> io_message_loop_;
+ // Task runner on which IPC calls are driven.
+ const scoped_refptr<base::SingleThreadTaskRunner> io_task_runner_;
// A map of stream ids to delegates; must only be accessed on
// |io_message_loop_|.
« no previous file with comments | « no previous file | chrome/renderer/media/cast_ipc_dispatcher.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698